@@ -1,11 +1,7 @@
 import platform
 
 # pylint: disable=unused-import
-from RPA.core.windows.helpers import (  # noqa: F401
-    IS_WINDOWS,
-    get_process_list,
-    is_numeric,
-)
+from RPA.core.windows.helpers import IS_WINDOWS, get_process_list  # noqa: F401
 
 
 def call_attribute_if_available(object_name, attribute_name):
